@@ -1,5 +1,6 @@
 # Calculate the Jacobian matrix for predictive levels or effects
-calc_jacob <- function(pred_values, covar_matrix, deriv_func){
+calc_jacob <- function(pred_values, covar_matrix, deriv_func, weights = NULL,
+                       ...){
 
   # covar_matrix: numeric matrix of covariates
   # pred_values: numeric vector of predicted values
@@ -13,9 +14,13 @@ calc_jacob <- function(pred_values, covar_matrix, deriv_func){
   # caluclate derivative of the predicted values
   x1 <- do.call(deriv_func, list(pred_values))
 
-  as.numeric(
-    crossprod(x1, covar_matrix)/nrow(covar_matrix)
-  )
+  if(is.null(weights)){
+    jacob <- crossprod(x1, covar_matrix)/nrow(covar_matrix)
+  } else {
+    jacob <- crossprod(x1 * weights, covar_matrix) / sum(weights)
+  }
+
+  as.numeric(jacob)
 
 }
 
