@@ -92,6 +92,9 @@ test_that("works correctly even when rows are dropped", {
 
   mod <- glm(outcome ~ treatment + distance,
              data = margex, family = 'binomial')
+  expect_warning(marg(mod, 'treatment', 'levels', at = NULL),
+                 'Dropping 5 rows due to missing data')
+
   z <- marg(mod, 'treatment', 'levels', at = NULL)[[1]]
 
   expect_equal(z$Margin, c(0.07911049, 0.25890416), tolerance = 0.0001)
